@@ -19,7 +19,7 @@ library(mrbin)
 
 
 ###################################################
-### code chunk number 4: mrbin.Rnw:167-182 (eval = FALSE)
+### code chunk number 4: mrbin.Rnw:167-183 (eval = FALSE)
 ###################################################
 ## mrbinResults<-mrbin(parameters=list(dimension="1D",
 ##              binwidth1D=.02,
@@ -32,6 +32,7 @@ library(mrbin)
 ##              PQNScaling="No",
 ##              fixNegatives="No",
 ##              logTrafo="No",
+## 			 useAsNames="Spectrum titles",
 ##              NMRfolders=c(system.file("extdata/1/10/pdata/10",package="mrbin"),
 ##                           system.file("extdata/2/10/pdata/10",package="mrbin"),
 ##                           system.file("extdata/3/10/pdata/10",package="mrbin"))
@@ -39,7 +40,7 @@ library(mrbin)
 
 
 ###################################################
-### code chunk number 5: mrbin.Rnw:185-203
+### code chunk number 5: mrbin.Rnw:186-205
 ###################################################
 mrbinResults<-mrbin(silent=TRUE,#this suppresses all interactive prompts
      setDefault=FALSE,
@@ -55,6 +56,7 @@ mrbinResults<-mrbin(silent=TRUE,#this suppresses all interactive prompts
              PQNScaling="No",
              fixNegatives="No",
              logTrafo="No",
+			 useAsNames="Spectrum titles",
              NMRfolders=c(system.file("extdata/1/10/pdata/10",package="mrbin"),
                           system.file("extdata/2/10/pdata/10",package="mrbin"),
                           system.file("extdata/3/10/pdata/10",package="mrbin"))
@@ -62,13 +64,13 @@ mrbinResults<-mrbin(silent=TRUE,#this suppresses all interactive prompts
 
 
 ###################################################
-### code chunk number 6: mrbin.Rnw:211-212
+### code chunk number 6: mrbin.Rnw:213-214
 ###################################################
 setNoiseLevels(mrbinResults,plotOnly=TRUE)
 
 
 ###################################################
-### code chunk number 7: mrbin.Rnw:222-227 (eval = FALSE)
+### code chunk number 7: mrbin.Rnw:224-229 (eval = FALSE)
 ###################################################
 ## mrbinResults<-mrbin(parameters=list(
 ##    NMRfolders=c("C:/Bruker/TopSpin3.6.1/data/guest/nmr/sample_1/10/pdata/10",
@@ -78,68 +80,68 @@ setNoiseLevels(mrbinResults,plotOnly=TRUE)
 
 
 ###################################################
-### code chunk number 8: mrbin.Rnw:246-247 (eval = FALSE)
+### code chunk number 8: mrbin.Rnw:248-249 (eval = FALSE)
 ###################################################
 ## mrbinResults<-setNoiseLevels(mrbinResults)
 
 
 ###################################################
-### code chunk number 9: mrbin.Rnw:259-260 (eval = FALSE)
+### code chunk number 9: mrbin.Rnw:261-262 (eval = FALSE)
 ###################################################
 ## mrbinResults<-removeNoise(mrbinResults)
 
 
 ###################################################
-### code chunk number 10: mrbin.Rnw:265-266 (eval = FALSE)
+### code chunk number 10: mrbin.Rnw:267-268 (eval = FALSE)
 ###################################################
 ## mrbinResults<-atnv(mrbinResults)
 
 
 ###################################################
-### code chunk number 11: mrbin.Rnw:273-275 (eval = FALSE)
+### code chunk number 11: mrbin.Rnw:275-277 (eval = FALSE)
 ###################################################
 ## mrbinResults<-setDilutionFactors(mrbinResults)
 ## mrbinResults<-dilutionCorrection(mrbinResults)
 
 
 ###################################################
-### code chunk number 12: mrbin.Rnw:281-282 (eval = FALSE)
+### code chunk number 12: mrbin.Rnw:283-284 (eval = FALSE)
 ###################################################
 ## mrbinResults<-PQNScaling(mrbinResults)
 
 
 ###################################################
-### code chunk number 13: mrbin.Rnw:289-290 (eval = FALSE)
+### code chunk number 13: mrbin.Rnw:291-292 (eval = FALSE)
 ###################################################
 ## mrbinResults<-logTrafo(mrbinResults)
 
 
 ###################################################
-### code chunk number 14: mrbin.Rnw:297-298 (eval = FALSE)
+### code chunk number 14: mrbin.Rnw:299-300 (eval = FALSE)
 ###################################################
 ## mrbinResults<-unitVarianceScaling(mrbinResults)
 
 
 ###################################################
-### code chunk number 15: mrbin.Rnw:303-304 (eval = FALSE)
+### code chunk number 15: mrbin.Rnw:305-306 (eval = FALSE)
 ###################################################
 ## plotResults(mrbinResults)
 
 
 ###################################################
-### code chunk number 16: mrbin.Rnw:312-313 (eval = FALSE)
+### code chunk number 16: mrbin.Rnw:314-315 (eval = FALSE)
 ###################################################
 ## mrbinResults<-removeSpectrum(mrbinResults)
 
 
 ###################################################
-### code chunk number 17: mrbin.Rnw:321-322 (eval = FALSE)
+### code chunk number 17: mrbin.Rnw:323-324 (eval = FALSE)
 ###################################################
 ## mrbinResults<-metadatamrbin(mrbinResults)
 
 
 ###################################################
-### code chunk number 18: mrbin.Rnw:331-334
+### code chunk number 18: mrbin.Rnw:333-336
 ###################################################
 mrbinResults<-metadatamrbin(mrbinResults,metadata=list(
   projectTitle="Test project",
@@ -147,13 +149,13 @@ mrbinResults<-metadatamrbin(mrbinResults,metadata=list(
 
 
 ###################################################
-### code chunk number 19: mrbin.Rnw:340-341
+### code chunk number 19: mrbin.Rnw:342-343
 ###################################################
 plotPCA(mrbinResults)
 
 
 ###################################################
-### code chunk number 20: mrbin.Rnw:351-360
+### code chunk number 20: mrbin.Rnw:353-362
 ###################################################
 mrbinResults<-editmetabolitesmrbin(mrbinResults,borders=matrix(c(
       1.346,1.324,21,23,
@@ -167,13 +169,13 @@ mrbinResults<-editmetabolitesmrbin(mrbinResults,borders=matrix(c(
 
 
 ###################################################
-### code chunk number 21: mrbin.Rnw:365-366
+### code chunk number 21: mrbin.Rnw:367-368
 ###################################################
 plotPCA(mrbinResults,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 22: mrbin.Rnw:377-385 (eval = FALSE)
+### code chunk number 22: mrbin.Rnw:379-387 (eval = FALSE)
 ###################################################
 ## mrbinResults<-editmrbin(
 ##   mrbinResults,
@@ -186,19 +188,19 @@ plotPCA(mrbinResults,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 23: mrbin.Rnw:390-391 (eval = FALSE)
+### code chunk number 23: mrbin.Rnw:392-393 (eval = FALSE)
 ###################################################
 ## mrbinResults$changeLog
 
 
 ###################################################
-### code chunk number 24: mrbin.Rnw:397-398
+### code chunk number 24: mrbin.Rnw:399-400
 ###################################################
 checkmrbin(mrbinResults)
 
 
 ###################################################
-### code chunk number 25: mrbin.Rnw:406-421 (eval = FALSE)
+### code chunk number 25: mrbin.Rnw:408-424 (eval = FALSE)
 ###################################################
 ## mrbinResults2D<-mrbin(setDefault=TRUE,parameters=list(dimension="2D",
 ##                binwidth2D=0.3,
@@ -211,6 +213,7 @@ checkmrbin(mrbinResults)
 ##                PQNScaling="No",
 ##                fixNegatives="No",
 ##                logTrafo="No",
+## 			   useAsNames="Spectrum titles",
 ##                NMRfolders=c(system.file("extdata/1/12/pdata/10",package="mrbin"),
 ##                        system.file("extdata/2/12/pdata/10",package="mrbin"),
 ##                        system.file("extdata/3/12/pdata/10",package="mrbin"))
@@ -218,7 +221,7 @@ checkmrbin(mrbinResults)
 
 
 ###################################################
-### code chunk number 26: mrbin.Rnw:423-441
+### code chunk number 26: mrbin.Rnw:426-445
 ###################################################
 mrbinResults2D<-mrbin(silent=TRUE,#this suppresses all interactive prompts
      setDefault=TRUE,
@@ -234,6 +237,7 @@ mrbinResults2D<-mrbin(silent=TRUE,#this suppresses all interactive prompts
                PQNScaling="No",
                fixNegatives="No",
                logTrafo="No",
+			   useAsNames="Spectrum titles",
                NMRfolders=c(system.file("extdata/1/12/pdata/10",package="mrbin"),
                        system.file("extdata/2/12/pdata/10",package="mrbin"),
                        system.file("extdata/3/12/pdata/10",package="mrbin"))
@@ -241,19 +245,19 @@ mrbinResults2D<-mrbin(silent=TRUE,#this suppresses all interactive prompts
 
 
 ###################################################
-### code chunk number 27: mrbin.Rnw:448-449
+### code chunk number 27: mrbin.Rnw:452-453
 ###################################################
 setNoiseLevels(mrbinResults2D,plotOnly=TRUE)
 
 
 ###################################################
-### code chunk number 28: mrbin.Rnw:461-462 (eval = FALSE)
+### code chunk number 28: mrbin.Rnw:465-466 (eval = FALSE)
 ###################################################
 ## load("C:/Users/User/Documents/mrbin.Rdata")
 
 
 ###################################################
-### code chunk number 29: mrbin.Rnw:470-473
+### code chunk number 29: mrbin.Rnw:474-477
 ###################################################
 mrbinResults2D<-metadatamrbin(mrbinResults,metadata=list(
   projectTitle="Test project",
@@ -261,13 +265,13 @@ mrbinResults2D<-metadatamrbin(mrbinResults,metadata=list(
 
 
 ###################################################
-### code chunk number 30: mrbin.Rnw:479-480
+### code chunk number 30: mrbin.Rnw:483-484
 ###################################################
 plotPCA(mrbinResults2D)
 
 
 ###################################################
-### code chunk number 31: mrbin.Rnw:486-495
+### code chunk number 31: mrbin.Rnw:490-499
 ###################################################
 mrbinResults2D<-editmetabolitesmrbin(mrbinResults2D,borders=matrix(c(
       1.346,1.324,21,23,
@@ -281,13 +285,13 @@ mrbinResults2D<-editmetabolitesmrbin(mrbinResults2D,borders=matrix(c(
 
 
 ###################################################
-### code chunk number 32: mrbin.Rnw:500-501
+### code chunk number 32: mrbin.Rnw:504-505
 ###################################################
 plotPCA(mrbinResults2D,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 33: mrbin.Rnw:510-533 (eval = FALSE)
+### code chunk number 33: mrbin.Rnw:514-537 (eval = FALSE)
 ###################################################
 ## results <- mrbin(parameters=list(dimension="1D",binMethod="Custom bin list",
 ##  specialBinList=matrix(c(5.45,5.2,0,160,
@@ -315,25 +319,37 @@ plotPCA(mrbinResults2D,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 34: mrbin.Rnw:553-554 (eval = FALSE)
+### code chunk number 34: mrbin.Rnw:557-558 (eval = FALSE)
 ###################################################
 ## mrbinResults<-mrbin()
 
 
 ###################################################
-### code chunk number 35: mrbin.Rnw:613-614 (eval = FALSE)
+### code chunk number 35: mrbin.Rnw:617-618 (eval = FALSE)
 ###################################################
 ## atnv(NMRdataMatrix,noiseLevelVector)
 
 
 ###################################################
-### code chunk number 36: mrbin.Rnw:629-630 (eval = FALSE)
+### code chunk number 36: mrbin.Rnw:633-634 (eval = FALSE)
 ###################################################
 ## mrplot()
 
 
 ###################################################
-### code chunk number 37: mrbin.Rnw:639-642 (eval = FALSE)
+### code chunk number 37: mrbin.Rnw:643-650
+###################################################
+mrplot(folders=c(system.file("extdata/1/12/pdata/10",package="mrbin"),
+                  system.file("extdata/1/10/pdata/10",package="mrbin"),
+                  system.file("extdata/2/10/pdata/10",package="mrbin"),
+                  system.file("extdata/3/10/pdata/10",package="mrbin")),
+        dimensions=c("2D","1D","1D","1D"),zoom=c(2.8,2.4,20,55),
+        highlight=c(2.564,2.537),
+        intensity1D=32,hideMenu=TRUE)
+
+
+###################################################
+### code chunk number 38: mrbin.Rnw:656-659 (eval = FALSE)
 ###################################################
 ## readBruker(dimension="1D",
 ##   folder=system.file("extdata/1/10/pdata/10",package="mrbin"))
@@ -341,7 +357,7 @@ plotPCA(mrbinResults2D,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 38: mrbin.Rnw:648-651 (eval = FALSE)
+### code chunk number 39: mrbin.Rnw:665-668 (eval = FALSE)
 ###################################################
 ## addToPlot(dimension="1D",
 ##   folder="C:/Bruker/TopSpin3.6.1/data/guest/nmr/sample_1/12/pdata/10")
@@ -349,7 +365,7 @@ plotPCA(mrbinResults2D,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 39: mrbin.Rnw:657-660 (eval = FALSE)
+### code chunk number 40: mrbin.Rnw:674-677 (eval = FALSE)
 ###################################################
 ## addToPlot(dimension="2D",
 ##   folder=system.file("extdata/1/12/pdata/10",package="mrbin"))
@@ -357,7 +373,7 @@ plotPCA(mrbinResults2D,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 40: mrbin.Rnw:665-672 (eval = FALSE)
+### code chunk number 41: mrbin.Rnw:682-689 (eval = FALSE)
 ###################################################
 ## zoom(left=4.6, right=2, top=10, bottom=150) #Exact zoom
 ## zoomIn() #Zoom in
@@ -369,7 +385,7 @@ plotPCA(mrbinResults2D,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 41: mrbin.Rnw:677-681 (eval = FALSE)
+### code chunk number 42: mrbin.Rnw:694-698 (eval = FALSE)
 ###################################################
 ## contMin() #Decrease minimum contour level (show more small peaks)
 ## contPlus() #Increase minimum contour level (remove small peaks)
@@ -378,7 +394,7 @@ plotPCA(mrbinResults2D,loadings=TRUE,annotate=TRUE)
 
 
 ###################################################
-### code chunk number 42: mrbin.Rnw:701-719 (eval = FALSE)
+### code chunk number 43: mrbin.Rnw:718-736 (eval = FALSE)
 ###################################################
 ## #First, define group membership and create the example feature data
 ## group<-factor(c(rep("Group1",4),rep("Group2",5)))
